@@ -2,9 +2,9 @@
  *
  *  $RCSfile: localedata.cxx,v $
  *
- *  $Revision: 1.22.18.1 $
+ *  $Revision: 1.22.18.4 $
  *
- *  last change: $Author: hr $ $Date: 2004/01/09 17:39:21 $
+ *  last change: $Author: vg $ $Date: 2004/08/27 13:49:08 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -58,7 +58,6 @@
  *
  *
  ************************************************************************/
-
 #include <localedata.hxx>
 
 #ifndef _RTL_USTRBUF_HXX_
@@ -129,7 +128,7 @@ static const struct {
 	{ "es_SV",  lcl_DATA_ES, NULL },
 	{ "es_UY",  lcl_DATA_ES, NULL },
 	{ "es_VE",  lcl_DATA_ES, NULL },
-
+	
 	{ "de_DE",  lcl_DATA_EURO, "de" },
 	{ "de_AT",  lcl_DATA_EURO, NULL },
 	{ "de_CH",  lcl_DATA_EURO, NULL },
@@ -147,6 +146,7 @@ static const struct {
 	{ "sv_SE",  lcl_DATA_EURO, "sv" },
 	{ "sv_FI",  lcl_DATA_EURO, NULL },
 	{ "ca_ES",  lcl_DATA_EURO, "ca" },
+	{ "gl_ES",  lcl_DATA_EURO, "gl" },
 	{ "cs_CZ",  lcl_DATA_EURO, "cs" },
 	{ "sk_SK",  lcl_DATA_EURO, "sk" },
 	{ "da_DK",  lcl_DATA_EURO, "da" },
@@ -169,6 +169,8 @@ static const struct {
 	{ "uk_UA",  lcl_DATA_EURO, "uk" },
 	{ "ro_RO",  lcl_DATA_EURO, "ro" },
 	{ "cy_GB",  lcl_DATA_EURO, "cy" },
+	{ "bg_BG",  lcl_DATA_EURO, "bg" },
+	{ "eu",     lcl_DATA_EURO, "eu" },
 
 	{ "ja_JP",  lcl_DATA_OTHERS, "ja" },
 	{ "ko_KR",  lcl_DATA_OTHERS, "ko" },
@@ -195,9 +197,9 @@ static const struct {
 	{ "af_ZA",  lcl_DATA_OTHERS, "af" },
 	{ "hu_HU",  lcl_DATA_OTHERS, "hu" },
 	{ "id_ID",  lcl_DATA_OTHERS, "id" },
+    { "ms_MY",  lcl_DATA_OTHERS, "ms" },
 
 //	{ "be_BY",  lcl_DATA, "be" },
-//	{ "bg_BG",  lcl_DATA, "bg" },
 //	{ "br_AE",  lcl_DATA, "br" },
 
 };
