@@ -2,9 +2,9 @@
  *
  *  $RCSfile: tplsetup.cxx,v $
  *
- *  $Revision: 1.20.114.2.2.3 $
+ *  $Revision: 1.20.114.2.2.5 $
  *
- *  last change: $Author: vg $ $Date: 2004/05/03 16:30:37 $
+ *  last change: $Author: vg $ $Date: 2004/08/27 13:30:35 $
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -58,7 +58,6 @@
  *
  *
  ************************************************************************/
-
 #define ENABLE_BYTESTRING_STREAM_OPERATORS	1
 
 #include <tools/solar.h>
@@ -229,6 +228,7 @@
 
 // Strings to replace $(vlang)
 #define	REPLACEMENT_ARABIC				ASCII_STR("arabic")
+#define REPLACEMENT_BASQUE				ASCII_STR("basque")
 #define	REPLACEMENT_CZECH				ASCII_STR("czech")
 #define	REPLACEMENT_DANISH				ASCII_STR("danish")
 #define	REPLACEMENT_DUTCH				ASCII_STR("dutch")
@@ -240,26 +240,30 @@
 #define	REPLACEMENT_GREEK				ASCII_STR("greek")
 #define	REPLACEMENT_HEBREW				ASCII_STR("hebrew")
 #define	REPLACEMENT_ITALIAN				ASCII_STR("italian")
-#define	REPLACEMENT_JAPANESE			ASCII_STR("japanese")
+#define	REPLACEMENT_JAPANESE				ASCII_STR("japanese")
 #define	REPLACEMENT_KOREAN				ASCII_STR("korean")
+#define	REPLACEMENT_LITHUANIAN				ASCII_STR("lithuanian")
 #define	REPLACEMENT_POLISH				ASCII_STR("polish")
 #define	REPLACEMENT_RUSSIAN				ASCII_STR("russian")
 #define	REPLACEMENT_SLOVAK				ASCII_STR("slovak")
 #define	REPLACEMENT_SPANISH				ASCII_STR("spanish")
+#define	REPLACEMENT_GALICIAN				ASCII_STR("galician")
 #define	REPLACEMENT_SWEDISH				ASCII_STR("swedish")
 #define	REPLACEMENT_TURKISH				ASCII_STR("turkish")
-#define	REPLACEMENT_NORWEGIAN			ASCII_STR("norwegian")
+#define	REPLACEMENT_NORWEGIAN				ASCII_STR("norwegian")
 #define	REPLACEMENT_NORWEGIAN_NYNORSK			ASCII_STR("norwegian_nynorsk")
-#define	REPLACEMENT_HUNGARIAN			ASCII_STR("hungarian")
-#define	REPLACEMENT_BULGARIAN			ASCII_STR("bulgarian")
-#define	REPLACEMENT_CHINESE_TRADITIONAL	ASCII_STR("chinese_traditional")
-#define	REPLACEMENT_CHINESE_SIMPLIFIED	ASCII_STR("chinese_simplified")
-#define	REPLACEMENT_PORTUGUESE			ASCII_STR("portuguese")
-#define	REPLACEMENT_SLOVENIAN			ASCII_STR("slovenian")
+#define	REPLACEMENT_HUNGARIAN				ASCII_STR("hungarian")
+#define	REPLACEMENT_BULGARIAN				ASCII_STR("bulgarian")
+#define	REPLACEMENT_CHINESE_TRADITIONAL			ASCII_STR("chinese_traditional")
+#define	REPLACEMENT_CHINESE_SIMPLIFIED			ASCII_STR("chinese_simplified")
+#define	REPLACEMENT_PORTUGUESE				ASCII_STR("portuguese")
+#define	REPLACEMENT_SLOVENIAN				ASCII_STR("slovenian")
 #define	REPLACEMENT_WELSH				ASCII_STR("welsh")
 #define REPLACEMENT_AFRIKAANS				ASCII_STR("afrikaans")
 #define REPLACEMENT_NORTHERNSOTHO			ASCII_STR("northernsotho")
 #define REPLACEMENT_ZULU				ASCII_STR("zulu")
+#define REPLACEMENT_TSWANA				ASCII_STR("tswana")
+#define REPLACEMENT_KANNADA				ASCII_STR("kannada")
 
 //------------------------------------------------------------------------
 
@@ -344,9 +348,11 @@ LanguageType Hierarchy_Impl::ConvertLanguage( USHORT nID ) const
 		case 02: return LANGUAGE_FRENCH_CANADIAN;
 		case 03: return LANGUAGE_PORTUGUESE;
 		case 07: return LANGUAGE_RUSSIAN;
+		case 10: return LANGUAGE_BASQUE;
 		case 26: return LANGUAGE_NORTHERNSOTHO;
 		case 27: return LANGUAGE_AFRIKAANS;
 		case 28: return LANGUAGE_ZULU;
+		case 29: return LANGUAGE_TSWANA;
 		case 30: return LANGUAGE_GREEK;
 		case 31: return LANGUAGE_DUTCH;
 		case 33: return LANGUAGE_FRENCH;
@@ -354,7 +360,7 @@ LanguageType Hierarchy_Impl::ConvertLanguage( USHORT nID ) const
         case 35: return LANGUAGE_FINNISH;
 		case 36: return LANGUAGE_HUNGARIAN;
         case 37: return LANGUAGE_CATALAN;
-        case 50: return LANGUAGE_SLOVENIAN;
+       		case 38: return LANGUAGE_GALICIAN;
 		case 39: return LANGUAGE_ITALIAN;
 		case 42: return LANGUAGE_CZECH;
 		case 43: return LANGUAGE_SLOVAK;
@@ -364,8 +370,10 @@ LanguageType Hierarchy_Impl::ConvertLanguage( USHORT nID ) const
 		case 47: return LANGUAGE_NORWEGIAN;
 		case 48: return LANGUAGE_POLISH;
 		case 49: return LANGUAGE_GERMAN;
+		case 50: return LANGUAGE_SLOVENIAN;
 		case 53: return LANGUAGE_WELSH;
 		case 55: return LANGUAGE_PORTUGUESE_BRAZILIAN;
+		case 58: return LANGUAGE_LITHUANIAN;
 		case 61: return LANGUAGE_ENGLISH_AUS;
         case 66: return LANGUAGE_THAI;
         	case 77: return LANGUAGE_ESTONIAN;
@@ -376,6 +384,7 @@ LanguageType Hierarchy_Impl::ConvertLanguage( USHORT nID ) const
 		case 88: return LANGUAGE_CHINESE_TRADITIONAL;
 		case 90: return LANGUAGE_TURKISH;
         case 91: return LANGUAGE_HINDI;
+		case 93: return LANGUAGE_KANNADA;
 		case 96: return LANGUAGE_ARABIC;
 		case 97: return LANGUAGE_HEBREW;
 		default: return LANGUAGE_ENGLISH_US;
@@ -1339,7 +1348,8 @@ OUString Hierarchy_Impl::SubstituteVariable( const OUString& rVar,
 				case LANGUAGE_SPANISH_NICARAGUA		:
 				case LANGUAGE_SPANISH_PUERTO_RICO	:	aReplacement = REPLACEMENT_SPANISH;
 														break ;
-
+				case LANGUAGE_GALICIAN	:	aReplacement = REPLACEMENT_GALICIAN;
+														break ;
 				case LANGUAGE_SWEDISH				:
 				case LANGUAGE_SWEDISH_FINLAND		:	aReplacement = REPLACEMENT_SWEDISH;
 														break ;
@@ -1377,6 +1387,17 @@ OUString Hierarchy_Impl::SubstituteVariable( const OUString& rVar,
                                case LANGUAGE_ZULU                              :       aReplacement = REPLACEMENT_ZULU;
                                                                                                                break ;
 
+                               case LANGUAGE_TSWANA                              :       aReplacement = REPLACEMENT_TSWANA;
+                                                                                                               break ;
+
+                               case LANGUAGE_BASQUE                              :       aReplacement = REPLACEMENT_BASQUE;
+                                                                                                               break ;
+
+                               case LANGUAGE_LITHUANIAN                              :       aReplacement = REPLACEMENT_LITHUANIAN;
+                                                                                                               break ;
+                               case LANGUAGE_KANNADA                              :       aReplacement = REPLACEMENT_KANNADA;
+                                                                                                               break ;
+
 				default								:	// no fallback any longer
 														DBG_ERRORFILE( "Language unknown." );
 														break ;
